<?php

/**
 * Project:     Mailto: A PHP class for obfuscating e-mail addresses from spam harvesters<br />
 * File:        Mailto.php<br />
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.<br /><br />
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.<br /><br />
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA<br /><br />
 *
 * Any modifications to the library should be indicated clearly in the source code
 * to inform users that the changes are not a part of the original software.<br /><br />
 *
 * @link http://www.debuggeddesigns.com/open-source-projects/mailto Mailto Link Obfuscator
 * @link http://www.debuggeddesigns.com/open-source-projects/mailto/code Download Latest Version
 * @link http://www.debuggeddesigns.com/open-source-projects/docs Online Documentation
 * @copyright 2008 Debugged Interactive Designs
 * @author debuggeddesigns <info@debuggeddesigns.com>
 * @version 0.0.0.1 (October 24, 2008)
 *
 */
 
 
/**
 * Mailto Link Obfuscator Class.
 *
 */
class Mailto {
	
	
	/**
	  * The encoding type used for encryption
	  *
	  * @access public
	  * @var string
	  */
	var $encoding_type;
	
	
	/**
	  * Class constructor.<br />
	  * Accepts a parameter 
	  *
	  * <code>
	  *   <?php
	  *   include 'Mailto.php';
	  *   $mailto = new Mailto();
	  *   ?>
	  * </code>
	  *
	  * @param string $encoding_type The encoding type used for encryption
	  * 
	  */
	  
	function Mailto($encoding_type = 'rot13') {
		$this->encoding_type = $encoding_type;
	}
  
  
    /**
	  * Create an encrypted mailto link using the e-mail address and content passed as parameters.
	  *
	  * <code>
	  *   <?php
	  *   include 'Mailto.php';
	  *   $mailto = new Mailto();
	  *   $mailto->createLink('info@debuggeddesigns.com','Debugged Interactive Designs');
	  *   ?>
	  * </code>
	  *
	  * @param string $addr  The e-mail address you want to hide from spam harvesters
	  * @param string $content  The term that will be clickable
	  * @return string  An encrypted anchor tag 
	  */
   
	function createLink($addr, $content) {
		
		if($this->encoding_type=='rot13'){
			//build the mailto link
			$unencrypted_link = '<a href="mailto:'.$addr.'">'.$content.'</a>';
			//build this for people with js turned off
			$noscript_link = '<noscript><span style="unicode-bidi:bidi-override;direction:rtl;">'.strrev($content.' > '.$addr.' <').'</span></noscript>';
			//put them together and encrypt
			$encrypted_link = '<script type="text/javascript">Rot13.write(\''.str_rot13($unencrypted_link).'\');</script>'.$noscript_link;
		}
		
		return $encrypted_link;
	}
}

?>